@@ -159,7 +159,7 @@ fi
             f.write("""
 %s/script/SuppGenerate.py --yaml %s --odir %s/Report/supp/ && \\
 
-%s/script/Report.R %s/Report %s
+%s/script/Report.py --odir %s/Report --yaml %s
 """%(self.pipe_dir, yaml_file, self.pro_dir,
     self.pipe_dir, self.pro_dir, self.yaml))
 
