@@ -23,12 +23,14 @@ def main(args):
     for file in files:
         if os.path.isdir(file):
             continue
-        dir = file.split("/")[-2]
+        dir = file.split("/")[1:-1]	        # remote_dest不能是指向文件, 否则将会创建一个同名目录
         remote_dest = args.remote
         if dir != ".":
-            remote_dest = os.path.join(args.remote,dir)
+            for d in dir:
+                remote_dest = os.path.join(remote_dest,d)
+        print(file,remote_dest)
         file = subprocess.getoutput("readlink -f %s" %(file))
-        os.system("BaiduPCS-Go upload %s %s" %(file,remote_dest))
+        #os.system("BaiduPCS-Go upload %s %s" %(file,remote_dest))
 
 if __name__ == "__main__":
-    main(sys.argv[1:])
\ No newline at end of file
+    main(sys.argv[1:])
